@@ -54,7 +54,6 @@ def cancel_task(loop: asyncio.AbstractEventLoop):
                     "task": task,
                 }
             )
-            print("is", task)
 
 
 def result_task(loop: asyncio.AbstractEventLoop):
@@ -79,9 +78,17 @@ class Client:
         The your-self token. It must be start 'xoxp-...'
     bot_token: :class:`str`
         The bot token. It must be start 'xoxb-...'
-    token: :class:Optional[`str`]
+    token: Optional[:class:`str`]
         App-level token. It is startwith 'xapp-...'
 
+        .. versionchanged:: 1.4.0
+            To optional.
+
+    logger: :class:`Logger.Logger`
+        Logger object.
+
+        .. versionadded:: 1.4.0
+
     loop: Optional[:class:`asyncio.AbstractEventLoop`]
         The :class:`asyncio.AbstractEventLoop` to use for asynchronous operations.
         Defaults to ``None``, in which case the default event loop is used via
@@ -93,6 +100,7 @@ class Client:
             user_token: str,
             bot_token: str,
             token: str = None,
+            logger: logging.Logger = None,
 
             loop: Optional[asyncio.AbstractEventLoop] = None,
             **options
@@ -104,7 +112,7 @@ class Client:
                 ]
             ]
         ] = {}
-        if not all([isinstance(t, str) for t in (user_token, bot_token, token)]):
+        if not all([isinstance(t, str) for t in (user_token, bot_token)]):
             raise TypeError("All token must be `str`")
 
         if not user_token.startswith("xoxp-"):
@@ -119,7 +127,7 @@ class Client:
         self.ws: SlackWebSocket = None
         self.user_token: str = user_token
         self.bot_token: str = bot_token
-        self.token: str = token
+        self.token: Optional[str] = token
         self.loop: asyncio.AbstractEventLoop = loop or asyncio.get_event_loop()
         self.http: HTTPClient = HTTPClient(self.loop, user_token=user_token, bot_token=bot_token, token=token)
         self._closed: bool = False
@@ -127,6 +135,7 @@ class Client:
         self._handlers: Dict[str, Callable] = {
             "ready": self._handle_ready
         }
+        self.logger = logger or _logger
         self.connection: ConnectionState = self._get_state(**options)
         self._teams: List[Dict[str, Any]]
         self.teams: Dict[str, Team] = {}
@@ -147,17 +156,15 @@ class Client:
 
     def dispatch(self, event: str, *args, **kwargs) -> None:
         method = f"on_{event}"
-        listeners = self._listeners.get(event)
         try:
             coro: Coro = getattr(self, method)
             _logger.info("dispatch event %s", method)
 
-        except AttributeError as attr:
-            # _logger.warning("Attribute Error `%s`", attr)
+        except AttributeError:
             pass
 
         except Exception as e:
-            _logger.error(type(e))
+            self.logger.error("%s occured", type(e), exc_info=e)
 
         else:
             self._schedule_event(coro, method, *args, **kwargs)
@@ -191,7 +198,7 @@ class Client:
             raise TypeError("event must be coroutine function.")
 
         setattr(self, coro.__name__, coro)
-        _logger.info("%s event was set", coro.__name__)
+        _logger.info("%s event set", coro.__name__)
         return coro
 
     def run(self) -> None:
@@ -202,8 +209,6 @@ class Client:
         or :meth:`connect` + :meth:`login`.
         Roughly Equivalent to: ::
 
-        .. codeblock:: python
-
             try:
                 loop.run_until_complete(start(*args, **kwargs))
             except KeyboardInterrupt:
@@ -211,6 +216,7 @@ class Client:
                 # cancel all tasks lingering
             finally:
                 loop.close()
+
         .. warning::
             This function must be the last function to call due to the fact that it
             is blocking. That means that registration of events or anything being
@@ -264,18 +270,22 @@ class Client:
 
     async def login(self) -> None:
         """
-        login as bot
+        Login as bot with websocket.
+        Get teams, channels and member data.
         """
         data = await self.http.login()
         self.teams, self.channels, self.members = await self.connection.initialize()
         await self.connect(data.get("url"))
 
     async def close(self) -> None:
+        """Close connection.
+        """
         self._closed = True
 
     async def connect(self, ws_url: str) -> None:
         """
         connect to slack-API
+
         Parameters
         ----------
         ws_url : :class:`str`
