@@ -6,9 +6,9 @@ from typing import Any, Dict, TYPE_CHECKING, Optional, Union
 
 import aiohttp
 
-from .utils import parse_exception
-from .errors import RateLimitException, SlackException
+from .errors import RateLimitException, ForbiddenException
 from .route import Route
+from .utils import parse_exception
 
 if TYPE_CHECKING:
     from .ws import SlackWebSocket
@@ -37,8 +37,8 @@ class HTTPClient:
         self.user_token: str = user_token
         self.token: str = token
         self.bot_token: str = bot_token
-        self.__session: aiohttp.ClientSession = None
-        self.ws: SlackWebSocket = None
+        self.__session: Optional[aiohttp.ClientSession] = None
+        self.ws: SlackWebSocket
 
     async def ws_connect(self, url: str):
         """It connects to a websocket and returns a websocket object
@@ -58,7 +58,9 @@ class HTTPClient:
     async def request(
             self,
             route: Route,
-            data: Optional[Dict[str, Any]] = None
+            data: Optional[Dict[str, Any]] = None,
+            query: Optional[Dict[str, str]] = None,
+            **kwargs
     ) -> Union[
         Dict[str, Any],
         str
@@ -67,6 +69,7 @@ class HTTPClient:
 
         Parameters
         ----------
+        query
         route : Route
         data : Optional[Dict[str, Any]]
 
@@ -77,40 +80,50 @@ class HTTPClient:
         headers = {
             "Authorization": f"Bearer {route.token}",
         }
-        params = {
+        attrs = {
             "headers": headers
         }
         if data is not None:
-            params["data"] = data
+            attrs["data"] = data
+
+        if query is not None:
+            query_url = "&".join(f"{k}={v}" for k, v in query.items())
+            route.url += f"?{query_url}"
 
         method = route.method
+
         url = route.url
 
-        async with self.__session.request(method, url, **params) as response:
+        async with self.__session.request(method, url, **attrs) as response:
             try:
                 _json = await response.json()
-                if _json.get("ok"):
-                    return _json
-
-                else:
-                    if _json.get("error") == "ratelimited":
-                        raise RateLimitException(_json)
+                is_ok = _json.get("ok")
+                if 300 > response.status >= 200:
+                    if is_ok is True:
+                        return _json
 
                     else:
-                        parse_exception(_json["error"])
+                        if _json.get("error") == "ratelimited":
+                            raise RateLimitException(_json)
+
+                        else:
+                            parse_exception(_json["error"])
+
+                elif response.status == 403:
+                    raise ForbiddenException()
 
             except json.JSONDecodeError:
                 return await response.text()
 
-    def send_message(self, route: Route, param):
+    def send_message(self, route: Route, data=None, query=None):
         """It takes a parameter, and returns a request
 
         Parameters
         ----------
+        query
+        data
         route
             a data to request.
-        param
-            a dictionary of parameters to send to the Slack API.
 
         Returns
         -------
@@ -119,10 +132,11 @@ class HTTPClient:
         """
         return self.request(
             route,
-            param
+            data=data,
+            query=query
         )
 
-    def delete_message(self, route: Route, param):
+    def delete_message(self, route: Route, data):
         """This function deletes a message from a chat
 
         Parameters
@@ -130,7 +144,7 @@ class HTTPClient:
         route
             a data to connect.
 
-        param
+        data
             keyword of send message.
 
         Returns
@@ -140,17 +154,20 @@ class HTTPClient:
         """
         return self.request(
             route,
-            param
+            data=data
         )
 
-    def create_channel(self, route: Route, param):
+    def create_channel(self, route: Route, data):
         return self.request(
             route,
-            param
+            data=data
         )
 
-    def join_channel(self, route: Route, param):
-        return self.request(route, param)
+    def join_channel(self, route: Route, data):
+        return self.request(route, data=data)
+
+    def get_anything(self, route: Route, data):
+        return self.request(route, data=data)
 
     async def login(self):
         """It gets a list of teams the bot is on, then gets the info for each team and stores it in a dictionary
